>>> I am working with git version of MM and Ubuntu 12.04.
>>> > > 
>>> > > I have three different physical serial (RS232) ports and they are not
>>> > > USB-to-serial. Now MM probes all of them. I want MM to automatically
>>> > > detect the port the modem is connected to but there're another devices
>>> > > controlled by another daemon.
>> > 
>> > 
>> > Most likely you'll need to include the check of "pnp" subsystem also
>> > when looking for the "ID_MM_PLATFORM_DRIVER_PROBE" udev tag. Your
>> > problem seems to be that the RS232 ports are not listed within the
>> > 'platform' subsystem, and teerefore the check for the
>> > ID_MM_PLATFORM_DRIVER_PROBE-based whitelist is not being done.
>> > 
>> > I now wonder if this 'pnp' subsystem can be considered fully equivalent
>> > to the 'platform' one for our purposes.
> Yes, PNP is basically equivalent to platform for us here.


Dan, wouldn't we need to explicitly require the device to be in the
whitelist for this subsystem? See attached patch.


-- 
Aleksander
>From dcf5106cc476ff3d3a1d1df2f2d0e98b8bf60c9c Mon Sep 17 00:00:00 2001
From: Aleksander Morgado <[email protected]>
Date: Sun, 9 Jun 2013 16:09:20 +0200
Subject: [PATCH] manager: require whitelist for devices in the 'pnp' subsystem

---
 src/mm-manager.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/mm-manager.c b/src/mm-manager.c
index 69134e1..7103a00 100644
--- a/src/mm-manager.c
+++ b/src/mm-manager.c
@@ -285,10 +285,11 @@ device_added (MMManager *manager,
         goto out;
     }
 
     /* If the physdev is a 'platform' device that's not whitelisted, ignore it */
     physdev_subsys = g_udev_device_get_subsystem (physdev);
     if (   physdev_subsys
-        && !strcmp (physdev_subsys, "platform")
+        && (   g_str_equal (physdev_subsys, "platform")
+            || g_str_equal (physdev_subsys, "pnp"))
         && !g_udev_device_get_property_as_boolean (physdev, "ID_MM_PLATFORM_DRIVER_PROBE")) {
         mm_dbg ("(%s/%s): port's parent platform driver is not whitelisted", subsys, name);
         goto out;
@@ -285,10 +285,11 @@ device_added (MMManager *manager,
     }
 
-    /* If the physdev is a 'platform' device that's not whitelisted, ignore it */
+    /* If the physdev is a 'platform' or 'pnp' device that's not whitelisted, ignore it */
     physdev_subsys = g_udev_device_get_subsystem (physdev);
     if (   physdev_subsys
-- 
1.8.2.1

_______________________________________________
networkmanager-list mailing list
[email protected]
https://mail.gnome.org/mailman/listinfo/networkmanager-list

Reply via email to